.. image:: https://travis-ci.org/watir/nerodia.svg?branch=master
    :target: https://travis-ci.org/watir/nerodia

Introduction
==============
Nerodia is a Python port of the Watir ruby gem. https://github.com/watir/watir

Supported Python Versions
=========================

* Python 2.7
* Python 3.3+

Installing
==========

If you have `pip <https://pip.pypa.io/>`_ on your system, you can simply install or upgrade::

    pip install -U nerodia

Alternately, you can download the source distribution from `PyPI <http://pypi.python.org/pypi/nerodia>`_ (e.g. nerodia-1.0.0.tar.gz), unarchive it, and run::

    python setup.py install
